window.Gleam.initSearch([{"doc":"translate","title":"translate","content":"# Translator for gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/translate)](https://hex.pm/packages/translate)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/translate/)\n[![Tests](https://github.com/andre-dasilva/translate/actions/workflows/test.yml/badge.svg)](https://github.com/andre-dasilva/translate/actions/workflows/test.yml)\n\n\nFurther documentation can be found at &lt;https://hexdocs.pm/translate&gt;.\n\n## Getting Started\n\n### Installation\n\n```sh\ngleam add translate\n```\n\n### Usage\n\nCreate a file for each locale in `src/`\n\n```md\nsrc/\n└── locale/\n    └── de-CH/\n        └── lang.json\n    └── en-US/\n        └── lang.json\n```\n\nde-CH/lang.json\n\n```json\n{\n    &quot;hello&quot;: {\n        &quot;value&quot;: &quot;Willkommen&quot;\n    },\n    &quot;amount_planets&quot;: {\n        &quot;value&quot;: &quot;Es gibt {AMOUNT} Planeten. Aber es waren mal {AMOUNT_BEFORE}.&quot;\n    }\n}\n```\n\nen-US/lang.json\n\n```json\n{\n    &quot;hello&quot;: {\n        &quot;value&quot;: &quot;Welcome&quot;\n    },\n    &quot;amount_planets&quot;: {\n        &quot;value&quot;: &quot;There are {CURRENT} planets&quot;\n    }\n}\n```\n\nAnd use the translator like this\n\n```gleam\nimport translate/translator\n\nlet assert Ok(translator) =\n  translator.new_translator(&quot;de-CH&quot;)\n  |&gt; translator.with_directory(&quot;src/locale&quot;)\n  |&gt; translator.from_json()\n\nlet assert Ok(value) =\n  translator\n  |&gt; translator.get_key(&quot;hello&quot;)\n  // value -&gt; Willkommen\n\nlet assert Ok(value) =\n  translator\n  |&gt; translator.get_key_with_args(&quot;amount_planets&quot;,  [#(&quot;CURRENT&quot;, &quot;7&quot;), #(&quot;BEFORE&quot;, &quot;8&quot;)])\n  // Es gibt 7 Planeten. Aber es waren mal 8.\n```\n\n## Development\n\nFork the project and clone it\n\nYou can run the tests with:\n\n```sh\ngleam test\n```\n","url":"index.html"},{"doc":"error","title":"TranslatorError","content":"pub type TranslatorError {\n  DirectoryNotSet\n  DirectoryNotFound\n  KeyNotFound(String)\n  JsonError(json.DecodeError)\n  FileError(simplifile.FileError)\n}\n\nDirectoryNotSet\n\n\nDirectoryNotFound\n\n\nKeyNotFound(String)\n\n\nJsonError(json.DecodeError)\n\n\nFileError(simplifile.FileError)\n\n\nSynonyms:\nerror.TranslatorError\nerror TranslatorError","url":"error.html#TranslatorError"},{"doc":"error","title":"error","content":"","url":"error.html"},{"doc":"header","title":"get_first_lang_from_accept_language_header","content":"pub fn get_first_lang_from_accept_language_header(\n  raw_header: String,\n) -&gt; Option(String)\n\nSynonyms:\nheader.get_first_lang_from_accept_language_header\nheader get_first_lang_from_accept_language_header","url":"header.html#get_first_lang_from_accept_language_header"},{"doc":"header","title":"parse_accept_language_header","content":"pub fn parse_accept_language_header(\n  raw_header: String,\n) -&gt; List(#(String, Float))\n Parses the accept langauge header according to:\n https://www.rfc-editor.org/rfc/rfc9110#field.accept-language\n\n e.g. fr-CH, fr;q=0.9, en;q=0.8, de;q=0.7, *;q=0.5\nSynonyms:\nheader.parse_accept_language_header\nheader parse_accept_language_header","url":"header.html#parse_accept_language_header"},{"doc":"header","title":"header","content":"","url":"header.html"},{"doc":"json","title":"read_file","content":"pub fn read_file(\n  directory: String,\n) -&gt; Result(Dict(String, Dict(String, String)), TranslatorError)\n\nSynonyms:\njson.read_file\njson read_file","url":"json.html#read_file"},{"doc":"json","title":"json","content":"","url":"json.html"},{"doc":"translator","title":"Translator","content":"pub type Translator {\n  Translator(\n    language: String,\n    directory: Option(String),\n    translations: Option(Dict(String, Dict(String, String))),\n  )\n}\n\nTranslator(\n  language: String,\n  directory: Option(String),\n  translations: Option(Dict(String, Dict(String, String))),\n)\n\n\nSynonyms:\ntranslator.Translator\ntranslator Translator","url":"translator.html#Translator"},{"doc":"translator","title":"from_json","content":"pub fn from_json(\n  translator: Translator,\n) -&gt; Result(Translator, TranslatorError)\n\nSynonyms:\ntranslator.from_json\ntranslator from_json","url":"translator.html#from_json"},{"doc":"translator","title":"get_key","content":"pub fn get_key(\n  translator: Translator,\n  key: String,\n) -&gt; Result(String, TranslatorError)\n\nSynonyms:\ntranslator.get_key\ntranslator get_key","url":"translator.html#get_key"},{"doc":"translator","title":"get_key_plural","content":"pub fn get_key_plural(\n  translator: Translator,\n  key: String,\n  count: Int,\n  args: List(#(String, String)),\n) -&gt; Result(String, TranslatorError)\n\nSynonyms:\ntranslator.get_key_plural\ntranslator get_key_plural","url":"translator.html#get_key_plural"},{"doc":"translator","title":"get_key_with_args","content":"pub fn get_key_with_args(\n  translator: Translator,\n  key: String,\n  args: List(#(String, String)),\n) -&gt; Result(String, TranslatorError)\n\nSynonyms:\ntranslator.get_key_with_args\ntranslator get_key_with_args","url":"translator.html#get_key_with_args"},{"doc":"translator","title":"new_translator","content":"pub fn new_translator(language: String) -&gt; Translator\n\nSynonyms:\ntranslator.new_translator\ntranslator new_translator","url":"translator.html#new_translator"},{"doc":"translator","title":"with_directory","content":"pub fn with_directory(\n  translator: Translator,\n  directory: String,\n) -&gt; Translator\n\nSynonyms:\ntranslator.with_directory\ntranslator with_directory","url":"translator.html#with_directory"},{"doc":"translator","title":"translator","content":"","url":"translator.html"}]);